@@ -1,7 +1,7 @@
 context("canvasXpress Charts - Differentiated groups")
 
-y <- read.table(system.file("extdata", "cX-toothgrowth-dat.txt.gz", package = "canvasXpress"), header = TRUE, sep = "\t", quote = "", row.names = 1, fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
-x <- read.table(system.file("extdata", "cX-toothgrowth-smp.txt.gz", package = "canvasXpress"), header = TRUE, sep = "\t", quote = "", row.names = 1, fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+y <- read.table(get_data( "cX-toothgrowth-dat.txt.gz"), header = TRUE, sep = "\t", quote = "", row.names = 1, fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+x <- read.table(get_data( "cX-toothgrowth-smp.txt.gz"), header = TRUE, sep = "\t", quote = "", row.names = 1, fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
 
 test_that("differentiated groups in boxplot 1", {
     result <- canvasXpress(data                    = y,
@@ -64,5 +64,5 @@ test_that("differentiated groups in boxplot 3", {
                            afterRender             = list(list("pivotX", list("supp"))))
 
     check_ui_test(result)
-    warning('Data points are not appearing on the chart (as of 25.9) unless it is resized manually or refreshed')
+    warning('Data points appearing on the chart are too small, unless it is resized manually or refreshed')
 })
