@@ -67,8 +67,16 @@ test_that("cXboxplot16", {
 
 test_that("cXboxplot17", {
     check_ui_test(cXboxplot17())
+
+    warning('Data points appearing on the chart are too small, unless it is resized manually or refreshed')
 })
 
 test_that("cXboxplot18", {
     check_ui_test(cXboxplot18())
+
+    warning('Data points appearing on the chart are too small, unless it is resized manually or refreshed')
+})
+
+test_that("cXboxplot19", {
+    check_ui_test(cXboxplot19())
 })
